@@ -3,4 +3,4 @@ from pydantic_numpy import NDArray
 
 
 def seal_mesh(vertices: NDArray, faces: NDArray) -> tuple[NDArray, NDArray]:
-    return pymeshfix.clean_from_arrays(vertices, faces, joincomp=True, verbose=False)
+    return pymeshfix.clean_from_arrays(vertices, faces, verbose=False)
